aboutsummaryrefslogtreecommitdiff
path: root/src/crypto
diff options
context:
space:
mode:
authorNaman Gera <namangera15@gmail.com>2021-04-09 03:48:14 +0000
committerEmmanuel Odeke <emmanuel@orijtech.com>2021-04-10 01:46:41 +0000
commit52bf14e0e8bdcd73f1ddfb0c4a1d0200097d3ba2 (patch)
treef74b0bff8523fa36dc932fd8b74450cabdd8aec9 /src/crypto
parent554d2c4f060ec42e30970dacff1e782250169323 (diff)
downloadgo-52bf14e0e8bdcd73f1ddfb0c4a1d0200097d3ba2.tar.gz
go-52bf14e0e8bdcd73f1ddfb0c4a1d0200097d3ba2.zip
all: fix spellings
This follows the spelling choices that the Go project has made for English words. https://github.com/golang/go/wiki/Spelling Change-Id: Ie7c586d2cf23020cb492cfff58c0831d2d8d3a78 GitHub-Last-Rev: e16a32cd225a275f73d236bcb33703986d110ded GitHub-Pull-Request: golang/go#45442 Reviewed-on: https://go-review.googlesource.com/c/go/+/308291 Run-TryBot: Ian Lance Taylor <iant@golang.org> TryBot-Result: Go Bot <gobot@golang.org> Reviewed-by: Ian Lance Taylor <iant@golang.org> Trust: Emmanuel Odeke <emmanuel@orijtech.com>
Diffstat (limited to 'src/crypto')
-rw-r--r--src/crypto/tls/handshake_server_test.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/crypto/tls/handshake_server_test.go b/src/crypto/tls/handshake_server_test.go
index 432b4cfe35..756d288cb3 100644
--- a/src/crypto/tls/handshake_server_test.go
+++ b/src/crypto/tls/handshake_server_test.go
@@ -1989,7 +1989,7 @@ func TestServerHandshakeContextCancellation(t *testing.T) {
// TestHandshakeContextHierarchy tests whether the contexts
// available to GetClientCertificate and GetCertificate are
// derived from the context provided to HandshakeContext, and
// that those contexts are cancelled after HandshakeContext has
// returned.
func TestHandshakeContextHierarchy(t *testing.T) {
c, s := localPipe(t)
@@ -2024,7 +2024,7 @@ func TestHandshakeContextHierarchy(t *testing.T) {
select {
case <-innerCtx.Done():
default:
- t.Errorf("GetClientCertificate context was not cancelled after HandshakeContext returned.")
+ t.Errorf("GetClientCertificate context was not canceled after HandshakeContext returned.")
}
}()
var innerCtx context.Context
@@ -2048,7 +2048,7 @@ func TestHandshakeContextHierarchy(t *testing.T) {
select {
case <-innerCtx.Done():
default:
- t.Errorf("GetCertificate context was not cancelled after HandshakeContext returned.")
+ t.Errorf("GetCertificate context was not canceled after HandshakeContext returned.")
}
if err := <-clientErr; err != nil {
t.Errorf("Unexpected client error: %v", err)
@@ -1989,7 +1989,7 @@ func TestServerHandshakeContextCancellation(t *testing.T) {
// available to GetClientCertificate and GetCertificate are
// derived from the context provided to HandshakeContext, and
-// that those contexts are cancelled after HandshakeContext has
+// that those contexts are canceled after HandshakeContext has
// returned.
func TestHandshakeContextHierarchy(t *testing.T) {